#!/bin/sh

#OPCH_IPCONF_PATH=/etc/infosvc/ip.conf

TOKENS_DIR="/etc/infosvc/tokens"
TMP_DIR="/tmp"
CFG_IP_ETH0_ADDR="cfg.ip.eth0.addr"
CFG_IP_ETH0_NETMASK="cfg.ip.eth0.mask"
CFG_IP_GATEWAY="cfg.ip.gateway"
CFG_IP_DNS1="cfg.ip.dns1"
CFG_IP_DNS2="cfg.ip.dns2"
CFG_IP_METACHANNEL="cfg.ip.metachannel"
CFG_IP_ETH0_MODE="cfg.ip.eth0.mode"
CFG_LOCALE_VENDORID="cfg.locale.vendorid"

RESOLV_CONF=/etc/resolv.conf

#below for a static ip configuration
DHCP=1
NULL_ADDRESS=0.0.0.0
IPADDRESS=0.0.0.0
NETMASK=0.0.0.0
NETADDR=0.0.0.0
IPADDRESS2=0.0.0.0
NETMASK2=0.0.0.0
NETADDR2=0.0.0.0
GW=0.0.0.0
DNS1=0.0.0.0
DNS2=0.0.0.0

INTERFACE="eth0"
INTERFACE_ALIAS0="eth0:0"

#"-nfq"
PARM1=$1
PARM2=$2
PARM_NO=$#

SET_VENDORID_OPTION=" -V "
VENDORID=""

if [ -e $TOKENS_DIR/$CFG_LOCALE_VENDORID ]; then
	VENDORID=`cat  $TOKENS_DIR/$CFG_LOCALE_VENDORID`
		
elif [ -e $TMP_DIR/$CFG_LOCALE_VENDORID ]; then
	VENDORID=`cat $TMP_DIR/$CFG_LOCALE_VENDORID`

fi

if [ $PARM_NO -ge 1 ]; then
	if [ $PARM1 = "static" ]; then
	DHCP=0
	echo "dhcpc script run in static mode"
	else
	DHCP=1
	echo "dhcpc script run in dhcp mode"
	fi
fi

if [ $PARM_NO -eq 2 ]; then
	if [ $PARM2 = "RUN_DHCP_TOKEN_TOOL" ]; then
	UDHCPC_OPTIONS="-E -b -p /tmp/udhcpc.pid -s /bin/dhcp_tokens -o 055=\\xF0 -o 055=\\xF1 -o 055=\\xF2 -o 055=\\xF3 -o 055=\\x2B -o ds57=\\x02\\x40"
	fi
else
	UDHCPC_OPTIONS="-E -b -p /tmp/udhcpc.pid  -o ds57=\\x02\\x40"
fi
 
getStaticTokensValue()
{
#default values defined in specs
  IPADDRESS=127.0.0.1
  NETMASK=255.255.255.248
  GW=0.0.0.0
  DNS1=172.26.23.3
  DNS2=0.0.0.0
  METACHANNEL=239.0.2.10:22222
  BOOTCAST_TIMEOUT=30

  if [ -e $TOKENS_DIR/$CFG_IP_ETH0_ADDR ]; then
    IPADDRESS=`cat $TOKENS_DIR/$CFG_IP_ETH0_ADDR`
  fi

  if [ -e $TOKENS_DIR/$CFG_IP_ETH0_NETMASK ]; then
    NETMASK=`cat $TOKENS_DIR/$CFG_IP_ETH0_NETMASK`
  fi

  if [ -e $TOKENS_DIR/$CFG_IP_GATEWAY ]; then
    GW=`cat $TOKENS_DIR/$CFG_IP_GATEWAY`
  fi

  if [ -e $TOKENS_DIR/$CFG_IP_DNS1 ]; then
    DNS1=`cat $TOKENS_DIR/$CFG_IP_DNS1`
  fi

  if [ -e $TOKENS_DIR/$CFG_IP_DNS2 ]; then
    DNS2=`cat $TOKENS_DIR/$CFG_IP_DNS2`
  fi

  if [ -e $TOKENS_DIR/$CFG_IP_METACHANNEL ]; then
    METACHANNEL=`cat $TOKENS_DIR/$CFG_IP_METACHANNEL`
  fi
}

setStaticIPConfiguration() 
{
	echo "Scripto setting static conf"
	if [ -f /tmp/udhcpc.pid ]; then
		kill -12 `cat /tmp/udhcpc.pid` && echo "DHCP client stopped.." || echo "Unable to stop DHCP client"
	fi
	ifconfig $INTERFACE 0.0.0.0
	[ "$IPADDRESS" != "" ] &&
	[ "$IPADDRESS" != "$NULL_ADDRESS" ] &&
	[ "$NETMASK" != "" ] &&
	[ "$NETMASK" != "$NULL_ADDRESS" ] &&
	ifconfig $INTERFACE $IPADDRESS netmask $NETMASK up

	[ "$GW" != "" ] &&
	[ "$GW" != "$NULL_ADDRESS" ] &&
	(route del default && route add default gw $GW dev $INTERFACE) ||
	route add default gw $GW dev $INTERFACE ;

	[ "$IPADDRESS2" != "" ] &&
	[ "$IPADDRESS2" != "$NULL_ADDRESS" ] &&
	[ "$NETMASK2" != "" ] &&
	[ "$NETMASK2" != "$NULL_ADDRESS" ] &&
	[ "$NETADDR2" != "" ] &&
	[ "$NETADDR2" != "$NULL_ADDRESS" ] &&
	ifconfig $INTERFACE_ALIAS0 $IPADDRESS2 netmask $NETMASK2 up && 
	route add -net $NETADDR2 netmask $NETMASK $INTERFACE_ALIAS0 ;

	[ "$DNS1" != "" ] && 
	[ "$DNS1" != "$NULL_ADDRESS" ] &&
	echo nameserver $DNS1 > $RESOLV_CONF ;

	[ "$DNS2" != "" ] && 
	[ "$DNS2" != "$NULL_ADDRESS" ] &&
	echo nameserver $DNS2 >> $RESOLV_CONF ;
}

setDynamicIPConfiguration() 
{
	echo "Scripto setting dynamic conf"
	if [ -f /tmp/udhcpc.pid ]; then
		echo "DHCP client already exists.."
		kill -10 `cat /tmp/udhcpc.pid` && echo "DHCP client started.." || 
		echo "Was unable to start DHCP client"
	else
		if [ -n "$VENDORID" ]; then #$VENDORID can have space. To add breckets it is added in line which executes udhcpc.
				udhcpc $UDHCPC_OPTIONS$SET_VENDORID_OPTION"$VENDORID"
		else
	  udhcpc $UDHCPC_OPTIONS
		fi
	fi

	#  udhcpc $UDHCPC_OPTIONS
}

#if [ -e $TOKENS_DIR/$CFG_IP_ETH0_MODE ]; then
#    MODE=`cat $TOKENS_DIR/$CFG_IP_ETH0_MODE`
#fi

#if [ -e $OPCH_IPCONF_PATH ]; then
#  IPCONF=`cat $OPCH_IPCONF_PATH`
#  if [ "$IPCONF" != "" ]; then
#     for str in $IPCONF; do
#       if [ "$ATTRIBUTE" != "" ]; then
#         case $ATTRIBUTE in
#           "DHCP" ) DHCP=$str; ;;
#           * ) ;;
#         esac
#         ATTRIBUTE=""
#       else 
#         ATTRIBUTE=$str
#       fi
#     done 
#  fi  
#fi

case $DHCP in
   "0" ) 
				getStaticTokensValue;
        setStaticIPConfiguration;
        break ;;
   "1" ) 
        setDynamicIPConfiguration;
        break ;;
   * ) 
        echo "config file error using dhcp" 
        setDynamicIPConfiguration;
        break ;;
esac

#echo "   IP="$IPADDRESS"   NM="$NETMASK"   GW="$GW
#echo "   IP2="$IPADDRESS2"   NM2="$NETMASK2"   NA2="$NETADDR2
#echo "   DNS1="$DNS1"   DNS2="$DNS2

